@@ -11,10 +11,26 @@ _LOGGER = logging.getLogger("LupusecStateMachine")
 class LupusecStateMachine:
     __devicesDict: Dict[DeviceClass, List[LupuDevice]] = dict()
     __panels: AlarmForm = None
+    __is_polling: bool = False
 
     def __init__(self, ip_address, username, password, time):
+        self.password = password
+        self.username = username
+        self.ip_address = ip_address
         self.__time = time
-        self.__lupu_service = LupusecSevice(ip_address, username, password)
+        self.__lupu_service = None
+
+    def connect(self):
+        self.__lupu_service = LupusecSevice(self.ip_address, self.username, self.password)
+
+    def update(self):
+        self.__refresh_devices()
+        self.__refresh_panels()
+
+    def poll(self):
+        if self.__is_polling:
+            return
+        self.__is_polling = True
         loop = asyncio.get_event_loop()
         loop.run_until_complete(self.__poll_devices())
         loop.run_until_complete(self.__poll_panels())
